@@ -19,6 +19,18 @@
 @CREATED    : July 24, 1992. (Peter Neelin, Montreal Neurological Institute)
 @MODIFIED   : 
  * $Log: minc.h,v $
+ * Revision 6.21  2010-05-19 03:44:25  stever
+ * Move definition of MNCAPI ahead of #include "minc_compat.h"; fix-up for
+ * previous check-in.
+ *
+ * Revision 6.20  2010-05-19 03:18:42  stever
+ * Ensure hdf5.h included before netcdf.h.
+ *
+ * Revision 6.19  2010-03-02 23:24:40  rotor
+ *  * libsrc/hdf_convenience.c: removed spurious debug output
+ *  * libsrc/minc.h: replaced MAX_NC_OPEN with 32
+ *  * libsrc/voxel_loop.c: replaced MAX_NC_OPEN with MI_MAX_NUM_ICV
+ *
  * Revision 6.18  2007/08/09 17:05:25  rotor
  *  * added some fixes of Claudes for chunking and internal compression
  *
@@ -140,10 +152,27 @@
               make no representations about the suitability of this
               software for any purpose.  It is provided "as is" without
               express or implied warranty.
-@RCSID      : $Header: /private-cvsroot/minc/libsrc/minc.h,v 6.18 2007/08/09 17:05:25 rotor Exp $ MINC (MNI)
+@RCSID      : $Header: /private-cvsroot/minc/libsrc/minc.h,v 6.21 2010-05-19 03:44:25 stever Exp $ MINC (MNI)
 ---------------------------------------------------------------------------- */
 
+#ifndef MNCAPI
+#if defined(_MSC_VER)
+/* If we are building on the Microsoft C compiler, we want to
+ * explicitly import all public functions from the DLL
+ */
+#define MNCAPI __declspec(dllimport)
+#else
+#define MNCAPI
+#endif /* _MSC_VER not defined */
+#endif /* MNCAPI not defined */
+
+#if MINC2
+#include <hdf5.h>
 #include <netcdf.h>
+#include "minc_compat.h"
+#else
+#include <netcdf.h>
+#endif
 
 #ifdef __cplusplus
 extern "C" {
@@ -373,7 +402,10 @@ extern "C" {
 
 /* Constants for image conversion variable (icv) properties */
 /* Maximum number of icv's allowed */
-#define MI_MAX_NUM_ICV MAX_NC_OPEN
+/* changed to 32 as netcdf 4.x no longer defines MAX_NC_OPEN */
+/* #define MI_MAX_NUM_ICV MAX_NC_OPEN */
+#define MI_MAX_NUM_ICV 32
+
 /* Default max and min for normalization */
 #define MI_DEFAULT_MAX 1.0
 #define MI_DEFAULT_MIN 0.0
@@ -461,16 +493,6 @@ extern "C" {
 #define MI_ERR_UNCOMPRESS       1349  /* Not able to uncompress file */
 
 /* MINC public functions */
-#ifndef MNCAPI
-#if defined(_MSC_VER)
-/* If we are building on the Microsoft C compiler, we want to
- * explicitly import all public functions from the DLL
- */
-#define MNCAPI __declspec(dllimport)
-#else
-#define MNCAPI
-#endif /* _MSC_VER not defined */
-#endif /* MNCAPI not defined */
 
 /* From netcdf_convenience.c */
 MNCAPI char *miexpand_file(char *path, char *tempfile, 
@@ -555,6 +577,10 @@ MNCAPI int miicv_attach(int icvid, int cdfid, int varid);
 MNCAPI void milog_init(const char *);
 MNCAPI int milog_set_verbosity(int);
 
+/* default voxel loop buffer size */
+#define MI2_DEF_BUFF_SIZE 4096
+#define MI2_DEF_MAX_MEM 104857
+
 #if MINC2
 
 /* New functions, not directly part of compatibility layer. */
@@ -585,9 +611,6 @@ struct mi2opts {
     int chunk_param;
 };
 
-#include <hdf5.h>
-#include "minc_compat.h"
-
 #define MI2_ISH5OBJ(x) (H5Iget_type(x) > 0)
 
 #else
