@@ -104,7 +104,8 @@ micopy_dimension(midimhandle_t dim_ptr, midimhandle_t *new_dim_ptr)
   else {
     handle->step = 0.0;
   }
-  if (dim_ptr->units == NULL) {
+  //check to make sure string is not empty or null
+  if (dim_ptr->units == NULL  || *dim_ptr->units == '\0') {
     handle->units = strdup("mm");
   }
   else {
@@ -193,19 +194,19 @@ micreate_dimension(const char *name, midimclass_t class, midimattr_t attr,
   switch (class) {
   case MI_DIMCLASS_SPATIAL:
     handle->class  = MI_DIMCLASS_SPATIAL;
-    if (strcmp(name, "xspace") == 0) {
+    if (strcmp(name, MIxspace) == 0) {
       handle->direction_cosines[MI2_X] = 1.0;
       handle->direction_cosines[MI2_Y] = 0.0;
       handle->direction_cosines[MI2_Z] = 0.0;
       handle->comments = strdup("X increases from patient left to right");
     }
-    else if (strcmp(name, "yspace") == 0) {
+    else if (strcmp(name, MIyspace) == 0) {
       handle->direction_cosines[MI2_X] = 0.0;
       handle->direction_cosines[MI2_Y] = 1.0;
       handle->direction_cosines[MI2_Z] = 0.0;
       handle->comments = strdup("Y increases from patient posterior to anterior");
     }
-    else if (strcmp(name, "zspace") == 0) {
+    else if (strcmp(name, MIzspace) == 0) {
       handle->direction_cosines[MI2_X] = 0.0;
       handle->direction_cosines[MI2_Y] = 0.0;
       handle->direction_cosines[MI2_Z] = 1.0;
@@ -363,7 +364,6 @@ miget_volume_dimensions(mihandle_t volume, midimclass_t class, midimattr_t attr,
   hsize_t number_of_dims; 
   int i=0, max_dims;
   int num_ret_dims = 0;
-  midimhandle_t hdim;
   
   if (volume == NULL) {
     return (MI_ERROR);
@@ -1331,13 +1331,31 @@ miget_dimension_start(midimhandle_t dimension, mivoxel_order_t voxel_order,
   }
   
  
-  if (voxel_order == 0) {
+  if (voxel_order == MI_ORDER_FILE) {
     *start_ptr = dimension->start;
   }
-  else {
+ else { // L.B March 16/2011, Properly reflect voxel ordering
+    if (dimension->flipping_order == MI_COUNTER_FILE_ORDER) { 
+      *start_ptr = dimension->start + (dimension->step * (dimension->length-1));
+    }
+    else if (dimension->flipping_order == MI_POSITIVE) {
+      if (dimension->step > 0) {
+      *start_ptr = dimension->start;
+      }
+      else {
+	*start_ptr = dimension->start + (dimension->step * (dimension->length-1));
+      }
+    }
+    else if (dimension->flipping_order == MI_NEGATIVE) {
+      if (dimension->step < 0) {
+	*start_ptr = dimension->start;
+      }
+      else {
     
-    *start_ptr = dimension->start + (dimension->step * (dimension->length-1));
-  }
+	*start_ptr = dimension->start + (dimension->step * (dimension->length-1));
+      }
+    }
+ }
   return (MI_NOERROR);
 }
 
