@@ -13,7 +13,7 @@
               make no representations about the suitability of this
               software for any purpose.  It is provided "as is" without
               express or implied warranty.
-@VERSION    : $Header: /private-cvsroot/minc/volume_io/Include/volume_io/geom_structs.h,v 1.23 2006/04/07 14:47:15 rotor Exp $
+@VERSION    : $Header: /private-cvsroot/minc/volume_io/Include/volume_io/geom_structs.h,v 1.24 2007-12-03 14:19:35 rotor Exp $
 ---------------------------------------------------------------------------- */
 
 /* ----------------------------- MNI Header -----------------------------------
@@ -79,9 +79,9 @@ typedef  struct
 
 #define  fill_Point( point, x, y, z ) \
             { \
-                Point_x(point) = (Point_coord_type) (x); \
-                Point_y(point) = (Point_coord_type) (y); \
-                Point_z(point) = (Point_coord_type) (z); \
+                Point_x(point) = (VIO_Point_coord_type) (x); \
+                Point_y(point) = (VIO_Point_coord_type) (y); \
+                Point_z(point) = (VIO_Point_coord_type) (z); \
             }
 
 /* ----------------------------- MNI Header -----------------------------------
@@ -116,9 +116,9 @@ typedef  struct
 
 #define  fill_Vector( vector, x, y, z ) \
             { \
-                Vector_x(vector) = (Point_coord_type) (x); \
-                Vector_y(vector) = (Point_coord_type) (y); \
-                Vector_z(vector) = (Point_coord_type) (z); \
+                Vector_x(vector) = (VIO_Point_coord_type) (x); \
+                Vector_y(vector) = (VIO_Point_coord_type) (y); \
+                Vector_z(vector) = (VIO_Point_coord_type) (z); \
             }
 
 /* ----------------------------- MNI Header -----------------------------------
